# geoexpress/core/formats.py

GEOEXPRESS_FORMATS = {
    "MG2": "mg2",
    "MG3": "mg3",
    "MG4": "mg4",

    "JP2": "jp2",
    "GMLJP2": "gmljp2",

    "TIFF": "tiff",

    "NITF": "nitf",
    "NITFJP2": "nitfjp2",

    "LAS": "las",
    "LAZ": "laz",
}
